﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Scheduling;
using MindFusion.Reporting.Wpf;

namespace WpfPlannerIntegration
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();

			calendar.BeginInit();
			calendar.ItemResources.Add(new Resource { Name = "Resource #1" });
			calendar.ItemResources.Add(new Resource { Name = "Resource #2" });
			calendar.ItemResources.Add(new Resource { Name = "Resource #3" });
			calendar.GroupType = MindFusion.Scheduling.Wpf.GroupType.GroupByResources;

			for (int i = 0; i < 100; i++)
			{
				var resource = calendar.ItemResources[i % calendar.ItemResources.Count];

				var app = new Appointment();
				app.StartTime = DateTime.Today;
				app.EndTime = DateTime.Today.AddHours(3);
				app.HeaderText = string.Format("Sample appointment for resource {0}", resource.Name);
				app.Resources.Add(resource);
				calendar.Schedule.Items.Add(app);
			}
			calendar.EndInit();


			var report = Report.FromDictionary(new Uri("ListBoundReport.xaml", UriKind.Relative), "listBoundReport");
			report.DataContext = calendar.Schedule.Resources;
			report.QueryDetails += (s, e) =>
			{
				DataRange sender = s as DataRange;
				if (sender != null)
				{
					if (sender.Name == "ItemsRange")
					{
						var resource = e.MasterRow as Resource;
						e.Details = calendar.Schedule.Items.Where(item => item.Resources.Contains(resource));
					}
				}
			};
			report.Run();

			var layout = report.Layout(new Size(8.5 * 96, 11 * 96), new Thickness(0.5 * 96), PageOrientation.Portrait);

			var renderTarget = new FixedDocumentRenderTarget();
			layout.RenderAllPages(renderTarget);

			viewer.Document = renderTarget.Document;
		}
	}
}
